# ps2mqtt
post psutil information to mqtt (easy integration with home-assistant)

## Install

```bash

$ sudo cp ps2mqtt.service /etc/systemd/system/

$ sudo systemctl enable ps2mqtt.service 

$ systemctl start ps2mqtt.service 

```
